%global prog cfengine
%global cfdir %{_var}/%{prog}

# Toggle running autoreconf, sometimes needed with buggy upstream
# tarballs (3.6.1)
%global enable_autotools 0

# Toggle lmdb / tokyocabinet
%if 0%{?fedora} >= 20 || 0%{?rhel} >= 6
%global _with_lmdb         1
%else
%global _with_tokyocabinet 1
%endif

# Toggle systemd integration
%if 0%{?fedora} > 17 || 0%{?rhel} > 6
%global enable_systemd 1
%endif

# The "_initrddir" macro is deprecated on rhel6 and later
# Use "_initddir" instead
%if 0%{?fedora} || 0%{?rhel} > 5
%global my_initddir %{_initddir}
%else
%global my_initddir %{_initrddir}
%endif

Name:      uio-cfengine
Version:   3.21.7
Release:   1%{?dist}
Summary:   CFEngine built for UiO

Group:     Applications/System
License:   GPLv3
URL:       http://cfengine.com/

Source0:   %{prog}-%{version}.tar.gz
Source1:   cf-execd
Source2:   cf-execd.service
Source3:   cfengine-prod01.pub
Source4:   cfengine-prod02.pub
Source5:   failsafe.cf
Source6:   only-one-cfexecd.cron
Source7:   cf-serverd
Source8:   cf-serverd.service
Source9:   cf-serverd.sysconfig
Source10:  tsd-cfengine-prod01.pub
Source11:  cf-key
Source12:  cf-key.service
Source13:  cfengine-prod03.pub
Source14:  cf-serverd.limits.conf
Source15:  tsd-cfengine-prod02.pub

%if 0%{?enable_systemd}
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
BuildRequires:    systemd
%else
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

%if 0%{?fedora} || 0%{?rhel} <= 7
Requires:  redhat-lsb
%endif

Conflicts: cfengine

%{?_with_tokyocabinet:BuildRequires: tokyocabinet-devel}
%{?_with_lmdb:BuildRequires: lmdb-devel}
BuildRequires: openssl-devel
BuildRequires: bison
BuildRequires: flex
BuildRequires: m4
BuildRequires: libacl-devel
BuildRequires: texlive-dvips
#BuildRequires: texinfo-tex
BuildRequires: pcre-devel
BuildRequires: libxml2-devel
BuildRequires: chrpath
BuildRequires: pam-devel
#BuildRequires: libyaml-devel
%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
%endif

BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%global key1_ipv4 root-129.240.2.47.pub
%global key1_ipv6 root-2001:700:100:425::47.pub
%global key1_md5  root-MD5=d6d7ced4347d09e7b89fad304dc2a51b.pub

%global key2_ipv4 root-129.240.2.78.pub
%global key2_ipv6 root-2001:700:100:540::78.pub
%global key2_md5  root-MD5=d4daf8b22ab56fa0aab0e8c1dc698035.pub

%global key3_ipv4 root-129.240.2.87.pub
%global key3_ipv6 root-2001:700:100:540::87.pub
%global key3_md5  root-MD5=1a5506524b375541e6c27e475a0098ed.pub

# TSD
%global tsdkey1_ipv6 root-2001:700:111:1::90.pub
%global tsdkey1_md5  root-MD5=9d3ef53f5d8851628979e335e9769fe2.pub

%global tsdkey2_ipv6 root-2001:700:111:1::2ac.pub
%global tsdkey2_md5  root-MD5=03d46580acf882af83ac3ee462df3646.pub

%description
CFEngine, or the configuration engine is an agent/software robot and a
very high level language for building expert systems to administrate
and configure large computer networks. CFEngine uses the idea of
classes and a primitive form of intelligence to define and automate
the configuration and maintenance of system state, for small to huge
configurations. CFEngine is designed to be a part of a computer immune
system. This package contains CFEngine and bootstrap files for UiO.


%package server
Summary:   Server component for CFEngine
Group:     Applications/System
Requires:  %{name} = %{version}-%{release}
%if 0%{?enable_systemd}
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
%else
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

# http://fedoraproject.org/wiki/EPEL:Packaging#noarch_subpackages
%if 0%{?fedora} || 0%{?rhel} >= 6
BuildArch: noarch
%endif

%description server
This package contains a SysV initscript or systemd unit file for
cf-serverd (CFEngine server daemon).

%package doc
Summary:   Documentation for CFEngine
Group:     Documentation
Requires:  %{name} = %{version}-%{release}

# http://fedoraproject.org/wiki/EPEL:Packaging#noarch_subpackages
%if 0%{?fedora} || 0%{?rhel} >= 6
BuildArch: noarch
%endif

%description doc
This package contains the documentation for CFEngine.


%prep
%setup -q -n %{prog}-%{version}


%build

%if 0%{?enable_autotools}
autoreconf -if
%endif

%configure \
    %{?_with_tokyocabinet:--with-tokyocabinet} \
    %{?_with_lmdb:--with-lmdb} \
    --disable-shared \
    --docdir=%{_defaultdocdir}/%{prog} \
    --with-workdir=/var/cfengine
make %{?_smp_mflags}


%install
rm -rf %{buildroot}

# Make install
make DESTDIR=%{buildroot} install

# Removing static libs if they are installed contrary to '--disable-shared'
[ -f %{buildroot}/%{_libdir}/libpromises.a ] && rm -f %{buildroot}/%{_libdir}/libpromises.a
[ -f %{buildroot}/%{_libdir}/libpromises.la ] && rm -f %{buildroot}/%{_libdir}/libpromises.la

# Creating dirs
mkdir -p %{buildroot}/opt/%{prog}/{sbin,inputs,ppkeys}

# Remove RPATH from binaries
for bin in %{buildroot}/%{_bindir}/*; do
    if file --mime-encoding $bin | grep -q binary; then
        chrpath -d $bin
    fi
done

# Putting binaries in opt
cp -a %{buildroot}/%{_bindir}/* %{buildroot}/opt/%{prog}/sbin

# Remove other installed items
rm -rf %{buildroot}/%{_var}

# Server public keys
install -p -m 0600 %{SOURCE3} %{buildroot}/opt/%{prog}/ppkeys/%{key1_md5}
install -p -m 0600 %{SOURCE3} %{buildroot}/opt/%{prog}/ppkeys/%{key1_ipv4}
install -p -m 0600 %{SOURCE3} %{buildroot}/opt/%{prog}/ppkeys/%{key1_ipv6}
install -p -m 0600 %{SOURCE4} %{buildroot}/opt/%{prog}/ppkeys/%{key2_md5}
install -p -m 0600 %{SOURCE4} %{buildroot}/opt/%{prog}/ppkeys/%{key2_ipv4}
install -p -m 0600 %{SOURCE4} %{buildroot}/opt/%{prog}/ppkeys/%{key2_ipv6}
install -p -m 0600 %{SOURCE13} %{buildroot}/opt/%{prog}/ppkeys/%{key3_md5}
install -p -m 0600 %{SOURCE13} %{buildroot}/opt/%{prog}/ppkeys/%{key3_ipv4}
install -p -m 0600 %{SOURCE13} %{buildroot}/opt/%{prog}/ppkeys/%{key3_ipv6}
install -p -m 0600 %{SOURCE10} %{buildroot}/opt/%{prog}/ppkeys/%{tsdkey1_md5}
install -p -m 0600 %{SOURCE10} %{buildroot}/opt/%{prog}/ppkeys/%{tsdkey1_ipv6}
install -p -m 0600 %{SOURCE15} %{buildroot}/opt/%{prog}/ppkeys/%{tsdkey2_md5}
install -p -m 0600 %{SOURCE15} %{buildroot}/opt/%{prog}/ppkeys/%{tsdkey2_ipv6}

# Failsafe config
install -p -m 0600 %{SOURCE5} %{buildroot}/opt/%{prog}/inputs/

# Remove some stuff we don't want
rm -f %{buildroot}/%{_defaultdocdir}/{ChangeLog,README.md}
rm -rf %{buildroot}/usr/lib

# Init script
%if 0%{?enable_systemd}
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE8} %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE12} %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}/systemd/system/cf-serverd.service.d
install -p -m 0644 %{SOURCE14} %{buildroot}%{_sysconfdir}/systemd/system/cf-serverd.service.d/limits.conf
%else
mkdir -p %{buildroot}%{my_initddir}
install -p -m 0755 %{SOURCE1} %{buildroot}%{my_initddir}
install -p -m 0755 %{SOURCE7} %{buildroot}%{my_initddir}
install -p -m 0755 %{SOURCE11} %{buildroot}%{my_initddir}
%endif

# Sysconfig file for cf-serverd
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 0644 %{SOURCE9} %{buildroot}%{_sysconfdir}/sysconfig/cf-serverd

# Cron job
mkdir -p %{buildroot}%{_sysconfdir}/cron.hourly
install -p -m 0755 %{SOURCE6} %{buildroot}%{_sysconfdir}/cron.hourly

# Create man pages
install -d -m 0755 %{buildroot}/%{_mandir}/man8
for file in %{buildroot}/%{_bindir}/cf-*; do
    bin=$(echo $file | awk -F/ '{print $NF}')
    if [ "$bin" == "cf-upgrade" ]; then
        continue
    fi
    %{buildroot}/%{_bindir}/$bin -M > %{buildroot}/%{_mandir}/man8/$bin.8
done


%post
%if 0%{?enable_systemd}
# The services should be enabled by default
/usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
/usr/bin/systemctl enable cf-execd.service >/dev/null 2>&1 || :
/usr/bin/systemctl enable cf-key.service >/dev/null 2>&1 || :
%else
# The services should be enabled by default
if [ $1 -eq 1 ] ; then
    # Initial installation
    # This adds the proper /etc/rc*.d links for the script
    /sbin/chkconfig --add cf-execd
    /sbin/chkconfig --add cf-key
fi
# This turns on the service
/sbin/chkconfig cf-execd on >/dev/null 2>&1 || :
/sbin/chkconfig cf-key on >/dev/null 2>&1 || :
%endif

# Remove obsolete/unused keys
rm %{cfdir}/ppkeys/root-{,129.240.2.19}.pub >/dev/null 2>&1 || :

# Copy keys if needed
mkdir -p %{cfdir}/ppkeys >/dev/null 2>&1 || :
for KEY in $(ls /opt/%{prog}/ppkeys); do
    cp /opt/%{prog}/ppkeys/$KEY %{cfdir}/ppkeys
done

# Clean old db4 cache files
find %{cfdir} -type f -name \*.db\* -exec rm -f {} ';'

# Remove TCDB cache files, if using LMDB
%if 0%{?_with_lmdb}
find %{cfdir} -type f -name \*.tcdb\* -exec rm -f {} ';'
%endif


%preun
%if 0%{?enable_systemd}
%systemd_preun cf-execd.service
%systemd_preun cf-key.service
%else
if [ $1 = 0 ] ; then
    # Actual deinstallation of package (not upgrade)
    /sbin/service cf-execd stop >/dev/null 2>&1
    /sbin/chkconfig --del cf-execd
    /sbin/service cf-key stop >/dev/null 2>&1
    /sbin/chkconfig --del cf-key
fi
%endif


%postun
%if 0%{?enable_systemd}
%systemd_postun_with_restart cf-execd.service
%systemd_postun cf-key.service
%else
if [ "$1" -ge "1" ] ; then
    # Upgrade of package
    /sbin/service cf-execd condrestart >/dev/null 2>&1 || :
fi
%endif


%post server
%if 0%{?enable_systemd}
%systemd_post cf-serverd.service
%else
if [ $1 -eq 1 ] ; then
    # This adds the proper /etc/rc*.d links for the script
    /sbin/chkconfig --add cf-serverd
fi
%endif


%preun server
%if 0%{?enable_systemd}
%systemd_preun cf-serverd.service
%else
if [ $1 = 0 ] ; then
    # Actual deinstallation of package (not upgrade)
    /sbin/service cf-serverd stop >/dev/null 2>&1
    /sbin/chkconfig --del cf-serverd
fi
%endif


%postun server
%if 0%{?enable_systemd}
%systemd_postun_with_restart cf-serverd.service
%else
if [ "$1" -ge "1" ] ; then
    # Upgrade of package
    /sbin/service cf-serverd condrestart >/dev/null 2>&1 || :
fi
%endif


%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog README.md
%dir /opt/%{prog}
%{_bindir}/*
%{_mandir}/man8/*
/opt/%{prog}/sbin/*
/opt/%{prog}/ppkeys/*.pub
/opt/%{prog}/inputs/*.cf
%if 0%{?enable_systemd}
%{_unitdir}/cf-execd.service
%{_unitdir}/cf-key.service
%else
%{my_initddir}/cf-execd
%{my_initddir}/cf-key
%endif
%{_sysconfdir}/cron.hourly/only-one-cfexecd.cron

%files server
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/sysconfig/cf-serverd
%if 0%{?enable_systemd}
%{_unitdir}/cf-serverd.service
%attr(755,root,root) %dir %{_sysconfdir}/systemd/system/cf-serverd.service.d
%config(noreplace) %{_sysconfdir}/systemd/system/cf-serverd.service.d/limits.conf
%else
%{my_initddir}/cf-serverd
%endif

%files doc
%defattr(-,root,root,-)
%{_defaultdocdir}/%{prog}


%changelog
* Wed Jun 18 2025 Trond Hasle Amundsen <trondham@uio.no> - 3.21.7-1
- Upstream release 3.21.7
- Update failsafe.cf

* Wed Apr 17 2024 Trond Hasle Amundsen <trondham@uio.no> - 3.21.4-1
- Upstream release 3.21.4
- Update failsafe.cf

* Thu Oct 12 2023 Trond Hasle Amundsen <trondham@uio.no> - 3.21.3-1
- Upstream release 3.21.3
- Update failsafe.cf

* Mon Jun 12 2023 Trond Hasle Amundsen <trondham@uio.no> - 3.21.2-1
- Upstream release 3.21.2
- Update failsafe.cf

* Mon May 29 2023 Trond Hasle Amundsen <trondham@uio.no> - 3.21.1-2
- only-one-cfexecd.cron: Allow 2 cf-execd processes due to changes in
  how cf-execd forks and executes cf-agent

* Tue May  2 2023 Trond Hasle Amundsen <trondham@uio.no> - 3.21.1-1
- First build of 3.21

* Sun Mar 26 2023 Trond Hasle Amundsen <trondham@uio.no> - 3.15.4-9
- Update failsafe.cf for f38

* Fri Nov 18 2022 Trond Hasle Amundsen <trondham@uio.no> - 3.15.4-8
- Update failsafe.cf for f37

* Wed Jun  8 2022 Trond Hasle Amundsen <trondham@uio.no> - 3.15.4-7
- Release bump for el9

* Fri Jun  3 2022 Trond Hasle Amundsen <trondham@uio.no> - 3.15.4-6
- Only require redhat-lsb for fedora and rhel <= 7

* Wed May 18 2022 Trond Hasle Amundsen <trondham@uio.no> - 3.15.4-5
- Buildrequire openssl1.1-devel for f36

* Wed Sep  8 2021 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.15.4-4
- Various systemd unit improvements

* Tue Aug 31 2021 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.15.4-3
- Change cf-key.service to report OK if service fails

* Fri Jun 25 2021 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.15.4-1
- Upstream release 3.15.4

* Tue Jun  1 2021 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.15.3-3
- Install binaries in /usr/bin instead of /usr/sbin

* Wed May  5 2021 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.15.3-1
- Upstream release 3.15.3

* Wed May  5 2021 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.12.2-11
- Update failsafe.cf for f34
- Fix wrong dates in changelog

* Fri Nov 13 2020 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.12.2-10
- Update failsafe.cf

* Tue Aug 18 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 3.12.2-9
- Wrong name for MD5 variant of key for tsd-cfengine-prod01

* Wed Aug 12 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 3.12.2-8
- Copy keys regardless of change or not

* Mon Jun 29 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 3.12.2-7
- Add key for new TSD 01

* Mon May 04 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 3.12.2-6
- Add second CFEngine server in TSD

* Fri Apr 03 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 3.12.2-5
- Added new TSD server (tsd-)cfengine-prod02.tsd.usit.no

* Thu Jan  9 2020 Mikael Dalsgard <mikael.dalsgard@usit.uio.no> - 3.12.2-4
- Reorder copyservers due to constrains on which server can talk to RHEL 8 systems

* Mon Nov  4 2019 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.12.2-3
- Update failsafe.cf for f31 and rhel8

* Fri Sep 13 2019 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.12.2-2
- Disable YAML support, was always buggy anyway
- Remove buildrequires texinfo-tex, non-existent on rhel8
- Update failsafe.cf for rhel8

* Tue Jul 23 2019 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.12.2-1
- Upstream release 3.12.2
- Update failsafe.cf

* Tue Jan 29 2019 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.10.5-1
- Upstream release 3.10.5
- Update failsafe.cf

* Tue Jun 12 2018 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.10.4-2
- Fix build dependency on dvips

* Tue Jun 12 2018 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.10.4-1
- Upstream release 3.10.4
- Update failsafe.cf

* Mon Apr 23 2018 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.10.3-1
- Upstream release 3.10.3
- Update failsafe.cf

* Fri Jul 21 2017 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.10.1-2
- Build with compat-openssl10 in F26 for now

* Fri Jul 21 2017 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.10.1-1
- Upstream release 3.10.1
- Update failsafe.cf

* Mon Apr  4 2016 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.7.3-1
- Upstream release 3.7.3
- Update failsafe.cf
- cf-serverd: Set nofile (ulimit -n) to 10000 in SysV init script
- Include systemd options file for cf-serverd
- BuildRequire libyaml-devel for YAML

* Mon Dec  7 2015 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.7.2-1
- Upstream release 3.7.2
- Update failsafe.cf

* Thu Jul 30 2015 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.6-1
- Upstream release 3.6.6
- Update failsafe.cf

* Fri Mar 13 2015 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.5-1
- Upstream release 3.6.5
- Properly remove lingering db4 or tcdb files

* Fri Mar  6 2015 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.4-3
- Rebuild due to missing dist macro on el5

* Fri Mar  6 2015 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.4-2
- Add support for RHEL5
- Update failsafe.cf

* Tue Feb 17 2015 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.4-1
- Upstream release 3.6.4
- Enable systemd watchdog for cf-serverd.service
- Enable systemd watchdog for cf-execd.service
- Update failsafe.cf

* Wed Jan  7 2015 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.3-2
- Add pubkey for new master host cfengine-prod03
- Change pubkey for TSD master host (IP address change)
- Update failsafe.cf

* Tue Dec  9 2014 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.3-1
- Upstream release 3.6.3

* Tue Nov 11 2014 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.2-1
- Upstream release 3.6.2
- Remove TCDB cache files, if using LMDB

* Mon Aug 11 2014 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.1-2
- Build with LMDB only on F20

* Thu Jul 31 2014 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.6.1-1
- Upstream release 3.6.1
- Updated failsafe.cf
- Switch to lmdb on fedora
- Various spec file improvements

* Tue Dec 17 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.3-2
- Updated failsafe.cf for f20

* Thu Dec 12 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.3-1
- Upstream release 3.5.3
- Updated failsafe.cf

* Fri Sep 20 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.2-4
- Make sure cf-execd and cf-key is enabled by default
- Don't enable cf-serverd by default

* Fri Sep 20 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.2-3
- Use new systemd macros for Fedora 18+

* Fri Sep 20 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.2-2
- Add SysV script and systemd unit file for cf-key

* Thu Sep  5 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.2-1
- Upstream release 3.5.2
- Add TSD cfengine server public key

* Mon Jul 15 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.1-1
- Upstream release 3.5.1

* Thu Jun 27 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.5.0-1
- Upstream release 3.5.0
- Updated failsafe.cf

* Mon Mar 18 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.4-1
- Upstream release 3.4.4

* Wed Feb 20 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.3-1
- Upstream release 3.4.3

* Mon Jan 28 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.2-6
- Improvements to only-one-cfexecd.cron

* Mon Jan 28 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.2-5
- Minor bugfix for /etc/sysconfig

* Mon Jan 28 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.2-4
- Added possibility to override cf-serverd arguments with a syconfig
  configuration file

* Mon Jan 28 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.2-3
- Updated failsafe.cf from upstream
- Added a server subpackage

* Thu Jan 24 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.2-2
- Fix build problem on Fedora

* Thu Jan 24 2013 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.4.2-1
- Upstream version 3.4.2
- Lots of changes for moving building to Koji
- Remove RHEL5 stuff, we don't build for for RHEL5
- Documentation in subpackage
- Add binaries in /usr/sbin as well

* Fri Jun 29 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.3.4-1
- Upstream version 3.3.4
- Remove old db4 files, no longer used
- Added code to remove tcdb files in post, if keys changed
- Don't build debuginfo packages

* Fri Apr 20 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.4-3
- Fixes for systems that use systemd instead of SysV init scripts

* Thu Mar 22 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.4-2
- Updates in failsafe.cf

* Mon Feb 20 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.4-1
- Upstream version 3.2.4
- Added manual pages
- Added documentation

* Tue Jan 17 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.3-6
- Remove obsolete/unused certificates in post section

* Tue Jan 17 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.3-5
- Remove cache files in post section

* Mon Jan 16 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.3-4
- Copy keys in post section, not postun

* Mon Jan 16 2012 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.3-3
- Added new master keys (MD5 keys, IPv6, new key for prod02)
- Copy master keys into /var/cfengine in postun section

* Sat Nov  5 2011 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.3-2
- Add cron job to monitor cf-execd

* Thu Nov  3 2011 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.2.3-1
- Bump Cfengine to version 3.2.3
- Add init script for cf-execd

* Wed Feb  2 2011 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.1.4-1
- Bump Cfengine to version 3.1.4

* Mon Jan 24 2011 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.1.3-1
- Bump Cfengine to version 3.1.3

* Thu Dec 16 2010 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.1.2-1
- Bump Cfengine to version 3.1.2

* Fri Nov 26 2010 Trond Hasle Amundsen <t.h.amundsen@usit.uio.no> - 3.0.5p1-1
- Initial release
